@@ -1,5 +1,5 @@
 package FAIR::AccessorBase;
-$FAIR::AccessorBase::VERSION = '0.230';
+$FAIR::AccessorBase::VERSION = '0.3';
 
 
 # ABSTRACT: The core Accessor functions
@@ -80,33 +80,113 @@ sub manageContainerGET {
 
 }
 
+sub makeSensibleStatement {
+      my ($self, $subject, $predicate, $obj) = @_;
+      my $NS = $self->Configuration->Namespaces();
+      my ($ns, $pred) = split /:/, $predicate;
+      my $statement;
+      if ($obj =~ /^http:/) {  # if its a URL
+            $statement = statement($subject,  $NS->$ns($pred), $obj); 
+      } elsif ((!$obj =~ /\s/) && ($obj =~ /\S+:\S+/)){  # if it looks like a qname tag
+            my ($vns,$vobj) = split /:/, $obj;
+            if ($NS->$vns($vobj)) {
+                  $statement = statement($subject,  $NS->$ns($pred), $NS->$vns($vobj));                   
+            } else {
+                  $statement = statement($subject,  $NS->$ns($pred), $obj); 
+            }                             
+      } else {
+            $statement = statement($subject,  $NS->$ns($pred), $obj); 
+      }
+      return $statement;
+      
+}
+
+
+#sub callMetadataAccessor {
+#    my ($self, $subject, $PATH, $model) = @_;
+#    
+#    my $result = $self->MetaContainer('PATH' => $PATH); # this subroutine is provided by the end-user in the Accessor script on the web
+#    $result = decode_json($result);
+#    
+#    $model->begin_bulk_ops();
+#    
+#    foreach my $CDE(keys %$result){
+#
+#      next unless $result->{$CDE}; 
+#      my $statement;
+#      my $values = $result->{$CDE};
+#      $values = [$values] unless (ref($values) =~ /ARRAY/);
+#      foreach my $value(@$values){
+#            $statement = $self->makeSensibleStatement($subject, $CDE, $value);
+#            $model->add_statement($statement);                               
+#      }
+#
+#    }
+#    $model->end_bulk_ops();
+#    
+#    # this code allows you to constrain the metadata... I don't like this idea anymore...
+#    #foreach my $CDE(@{$self->Configuration->MetadataElements}){  # common metadata, plus locally specified metadata elements
+#    #    next unless $result->{$CDE};  # this will reject any metadata that you didn't specify in the configuration
+#    #    my ($namespace, $term) = split /:/, $CDE;
+#    #    
+#    #    if (ref($result->{$CDE}) =~ /ARRAY/) {
+#    #        foreach (@{$result->{$CDE}}){
+#    #            my $statement = statement($subject, $ns->$namespace($term), $_); 
+#    #            $model->add_statement($statement);
+#    #        }
+#    #    } else {                    
+#    #        my $statement = statement($subject,$ns->$namespace($term), $result->{$CDE}); 
+#    #        $model->add_statement($statement);
+#    #    }
+#    #}
+#}
+
+
 
 sub callMetadataAccessor {
     my ($self, $subject, $PATH, $model) = @_;
-
     
     my $result = $self->MetaContainer('PATH' => $PATH); # this subroutine is provided by the end-user in the Accessor script on the web
     $result = decode_json($result);
     
+    $model->begin_bulk_ops();
     
-    my $ns = $self->Configuration->Namespaces();
-    
-    foreach my $CDE(@{$self->Configuration->MetadataElements}){  # common metadata, plus locally specified metadata elements
-        next unless $result->{$CDE};  # this will reject any metadata that you didn't specify in the configuration
-        my ($namespace, $term) = split /:/, $CDE;
-        
-        if (ref($result->{$CDE}) =~ /ARRAY/) {
-            foreach (@{$result->{$CDE}}){
-                my $statement = statement($subject, $ns->$namespace($term), $_); 
-                $model->add_statement($statement);
-            }
-        } else {                    
-            my $statement = statement($subject,$ns->$namespace($term), $result->{$CDE}); 
-            $model->add_statement($statement);
-        }
-    }
-}
+    foreach my $CDE(keys %$result){
 
+      next unless $result->{$CDE}; 
+      my $statement;
+      my $values = $result->{$CDE};
+      $values = [$values] unless (ref($values) =~ /ARRAY/);
+      my $temprdf;  # doing this to make the import more efficient... I hope!
+      foreach my $value(@$values){
+            $statement = $self->makeSensibleStatement($subject, $CDE, $value);
+            my $str = $statement->as_string;  # almost n3 format... need to fix it a bit...
+            $str =~ s/^\(triple\s//;
+            $str =~ s/\)$/./;
+            $temprdf .= "$str\n";  # this is RDF in n3 format
+      }
+      my $parser     = RDF::Trine::Parser->new( 'ntriples' );
+      $parser->parse_into_model( "http://example.org/", $temprdf, $model );
+ 
+    }
+    $model->end_bulk_ops();
+    
+    # this code allows you to constrain the metadata... I don't like this idea anymore...
+    #foreach my $CDE(@{$self->Configuration->MetadataElements}){  # common metadata, plus locally specified metadata elements
+    #    next unless $result->{$CDE};  # this will reject any metadata that you didn't specify in the configuration
+    #    my ($namespace, $term) = split /:/, $CDE;
+    #    
+    #    if (ref($result->{$CDE}) =~ /ARRAY/) {
+    #        foreach (@{$result->{$CDE}}){
+    #            my $statement = statement($subject, $ns->$namespace($term), $_); 
+    #            $model->add_statement($statement);
+    #        }
+    #    } else {                    
+    #        my $statement = statement($subject,$ns->$namespace($term), $result->{$CDE}); 
+    #        $model->add_statement($statement);
+    #    }
+    #}
+}
 # ====================== END OF STAGE1 SUBROUTINES
 
 
@@ -141,18 +221,29 @@ sub callDataAccessor {
 
     my $distributions = $result->{'distributions'};
       foreach my $format(keys %$distributions){
+            next unless ($format =~ /\S/);
             my $location = $distributions->{$format};
             $location = [$location] unless (ref($location) =~ /ARRAY/);  # force it to be always be an arrayref just for code clarity
             
             foreach my $loc(@$location){
+                  next unless ($loc =~ /\S/);
                   my $statement = statement($URL, $NS->dcat('distribution'), $loc);
                   $model->add_statement($statement);
                   
                   $statement = statement($loc, $NS->rdf('type'), $NS->dcat('Distribution'));
                   $model->add_statement($statement);
                   
+                  $statement = statement($loc, $NS->rdf('type'), $NS->dctypes('Dataset'));
+                  $model->add_statement($statement);
+
                   $statement = statement($loc, $NS->dc('format'), $format);
                   $model->add_statement($statement);
+
+                  if (($format =~ /turtle/) || ($format =~ /rdf/) || ($format =~ /quads/)) {
+                        $statement = statement($loc, $NS->rdf('type'), $NS->void('Dataset'));
+                        $model->add_statement($statement);
+                  }
+                  
             
                   $statement = statement($loc, $NS->dcat('downloadURL'), $loc);
                   $model->add_statement($statement);
@@ -166,21 +257,10 @@ sub callDataAccessor {
             foreach my $predicate(keys %$metadata){
                   my $values = $metadata->{$predicate};
                   $values = [$values] unless (ref($values) =~ /ARRAY/);
-
-                  my ($ns,$pred) = split /:/, $predicate;
                                     
                   foreach my $value(@$values) {
-                        if ($value =~ /^http:/) {  # if its a URL
-                              my $statement = statement($URL,  $NS->$ns($pred), $value); 
-                              $model->add_statement($statement); 
-                        } elsif ($value =~ /\S+:\S+/){  # if it looks like a qname tag
-                              my ($vns,$vobj) = split /:/, $value;
-                              my $statement = statement($URL,  $NS->$ns($pred), $NS->$vns($vobj)); 
-                              $model->add_statement($statement); 
-                        } else {
-                              my $statement = statement($URL,  $NS->$ns($pred), $value); 
-                              $model->add_statement($statement);                               
-                        }
+                        my $statement = $self->makeSensibleStatement($URL, $predicate, $value);
+                        $model->add_statement($statement);                               
                   }
             }
       }
@@ -222,7 +302,8 @@ sub printResourceHeader {
         my $ETAG = $self->Configuration->ETAG_Base();
 	my $entity = $ENV{'PATH_INFO'};
 	$entity =~ s/^\///;
-	print "Content-Type: text/turtle\n";
+#	print "Content-Type: text/turtle\n";
+	print "Content-Type: application/rdf+xml\n";
 	print "ETag: \"$ETAG"."_"."$entity\"\n";
 	print "Allow: GET,OPTIONS,HEAD\n";
 	print 'Link: <http://www.w3.org/ns/ldp#Resource>; rel="type"'."\n\n";
@@ -232,7 +313,8 @@ sub printResourceHeader {
 sub printContainerHeader {
 	my ($self) = @_;
         my $ETAG = $self->Configuration->ETAG_Base();
-	print "Content-Type: text/turtle\n";
+#	print "Content-Type: text/turtle\n";
+	print "Content-Type: application/rdf+xml\n";
 	print "ETag: \"$ETAG\"\n";
 	print "Allow: GET,OPTIONS,HEAD\n";
 	print 'Link: <http://www.w3.org/ns/ldp#BasicContainer>; rel="type",'."\n";
@@ -255,7 +337,8 @@ sub manageHEAD {
 
 sub serializeThis{
     my ($self, $model) = @_;
-    my $serializer = RDF::Trine::Serializer->new('turtle');  # TODO - this should work with content negotiation
+#    my $serializer = RDF::Trine::Serializer->new('turtle');  # the turtle serializer is simply too slow to use...
+    my $serializer = RDF::Trine::Serializer->new('rdfxml');  # TODO - this should work with content negotiation
     print $serializer->serialize_model_to_string($model);
 }
 
@@ -305,7 +388,7 @@ FAIR::AccessorBase - The core Accessor functions
 
 =head1 VERSION
 
-version 0.230
+version 0.3
 
 =head1 AUTHOR
 
