@@ -1,5 +1,5 @@
 package FAIR::AccessorConfig;
-$FAIR::AccessorConfig::VERSION = '0.230';
+$FAIR::AccessorConfig::VERSION = '0.3';
 
 
 # ABSTRACT: The key/value of the current configuration of the Accessor
@@ -114,6 +114,11 @@ sub BUILD {
     die "can't set namespace $!\n" unless ($NS->SET(edam => "http://edamontology.org/"));
     die "can't set namespace $!\n" unless ($NS->SET(sio => "http://semanticscience.org/resource/"));
     die "can't set namespace $!\n" unless ($NS->SET(example => 'http://example.org/ns#'));
+    die "can't set namespace $!\n" unless ($NS->SET(prov => 'http://www.w3.org/ns/prov#'));
+    die "can't set namespace $!\n" unless ($NS->SET(dctypes => 'http://purl.org/dc/dcmitype/'));
+    die "can't set namespace $!\n" unless ($NS->SET(pav => 	'http://purl.org/pav/'));
+    die "can't set namespace $!\n" unless ($NS->SET(schemaorg => 'http://schema.org/'));
+    die "can't set namespace $!\n" unless ($NS->SET(void => 'http://rdfs.org/ns/void#'));
 
     foreach my $abbreviation(keys %{$self->localNamespaces()}){
 	my $namespace = $self->localNamespaces()->{$abbreviation};
@@ -140,7 +145,7 @@ FAIR::AccessorConfig - The key/value of the current configuration of the Accesso
 
 =head1 VERSION
 
-version 0.230
+version 0.3
 
 =head1 AUTHOR
 
