@@ -1,5 +1,5 @@
 package FAIR::Profile::Parser;
-$FAIR::Profile::Parser::VERSION = '0.230';
+$FAIR::Profile::Parser::VERSION = '0.3';
 
 # ABSTRACT: Parser that reads FAIR Profile RDF and creates a FAIR::Profile object
 
@@ -81,13 +81,13 @@ sub parse {
 				
 			die "file $filename does not exist" unless (-e $filename);
 		#	open(IN, "$filename") || die "can't open input file $!\n";
-			RDF::Trine::Parser->parse_file_into_model( "", $filename, $model );
+			RDF::Trine::Parser->parse_file_into_model( "http://datafairport.org/fakepath/", $filename, $model );
 		
 		}
 	} elsif ($data){
 		die "you can't pass data without telling me the ->data_format" unless ($self->data_format);
 		my $parser = RDF::Trine::Parser->new($self->data_format);
-		$parser->parse_into_model("", $data, $model );
+		$parser->parse_into_model("http://datafairport.org/fakepath/", $data, $model );
 	}
 	
 	
@@ -354,7 +354,7 @@ FAIR::Profile::Parser - Parser that reads FAIR Profile RDF and creates a FAIR::P
 
 =head1 VERSION
 
-version 0.230
+version 0.3
 
 =head1 SYNOPSIS
 
